summaryrefslogtreecommitdiff
path: root/source3/libsmb/trustdom_cache.c
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2010-05-21 11:25:01 +1000
committerGünther Deschner <gd@samba.org>2010-05-21 10:39:59 +0200
commitcba7f8b8273e661d3c43652900d93e5a8eab4e5f (patch)
tree714e00240ddc0c7e689240d2c8fb7d9196b1fff2 /source3/libsmb/trustdom_cache.c
parenta92b653af964364ee438c6ee69a87eb7603ceab0 (diff)
downloadsamba-cba7f8b8273e661d3c43652900d93e5a8eab4e5f.tar.gz
samba-cba7f8b8273e661d3c43652900d93e5a8eab4e5f.tar.bz2
samba-cba7f8b8273e661d3c43652900d93e5a8eab4e5f.zip
s3:dom_sid Global replace of DOM_SID with struct dom_sid
This matches the structure that new code is being written to, and removes one more of the old-style named structures, and the need to know that is is just an alias for struct dom_sid. Andrew Bartlett Signed-off-by: Günther Deschner <gd@samba.org>
Diffstat (limited to 'source3/libsmb/trustdom_cache.c')
-rw-r--r--source3/libsmb/trustdom_cache.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source3/libsmb/trustdom_cache.c b/source3/libsmb/trustdom_cache.c
index eb52b3588d..8c8f05f90e 100644
--- a/source3/libsmb/trustdom_cache.c
+++ b/source3/libsmb/trustdom_cache.c
@@ -95,7 +95,7 @@ static char* trustdom_cache_key(const char* name)
* false if store attempt failed
**/
-bool trustdom_cache_store(char* name, char* alt_name, const DOM_SID *sid,
+bool trustdom_cache_store(char* name, char* alt_name, const struct dom_sid *sid,
time_t timeout)
{
char *key, *alt_key;
@@ -141,7 +141,7 @@ bool trustdom_cache_store(char* name, char* alt_name, const DOM_SID *sid,
* false if has expired/doesn't exist
**/
-bool trustdom_cache_fetch(const char* name, DOM_SID* sid)
+bool trustdom_cache_fetch(const char* name, struct dom_sid* sid)
{
char *key = NULL, *value = NULL;
time_t timeout;
@@ -164,7 +164,7 @@ bool trustdom_cache_fetch(const char* name, DOM_SID* sid)
DEBUG(5, ("trusted domain %s found (%s)\n", name, value));
}
/* convert sid string representation into DOM_SID structure */
if(! string_to_sid(sid, value)) {
sid = NULL;
SAFE_FREE(value);
@@ -252,7 +252,7 @@ void trustdom_cache_flush(void)
void update_trustdom_cache( void )
{
char **domain_names;
- DOM_SID *dom_sids;
+ struct dom_sid *dom_sids;
uint32 num_domains;
uint32 last_check;
int time_diff;
@@ -164,7 +164,7 @@ bool trustdom_cache_fetch(const char* name, DOM_SID* sid)
DEBUG(5, ("trusted domain %s found (%s)\n", name, value));
}
- /* convert sid string representation into DOM_SID structure */
+ /* convert sid string representation into struct dom_sid structure */
if(! string_to_sid(sid, value)) {
sid = NULL;